@@ -14,6 +14,20 @@ def get_class_by_path(path):
     return mod
 
 
+def get_measure_unit_choices(include_measure=False):
+    measures = build_measure_list()
+    final_list = []
+    for measure_name, measure in measures.items():
+        measure_items = []
+        for unit_name, _ in measure.UNITS.items():
+            measure_items.append(
+                ('%s.%s' % (measure_name, unit_name, ) if include_measure else unit_name, unit_name)
+            )
+        this_measure = tuple([measure_name, tuple(measure_items)])
+        final_list.append(this_measure)
+    return tuple(final_list)
+
+
 def build_measure_list():
     from django.contrib.gis.measure import MeasureBase as DjangoMeasureBase
     from django_measurement.base import MeasureBase
@@ -24,7 +38,7 @@ def build_measure_list():
         possible_measure = getattr(measure, possible_measure_name)
         if not inspect.isclass(possible_measure):
             continue
-        if issubclass(possible_measure, (MeasureBase, DjangoMeasureBase, )):
+        if issubclass(possible_measure, (MeasureBase, DjangoMeasureBase, )) and MeasureBase != possible_measure:
             measures[possible_measure_name] = possible_measure
     for overridden_measure_name, cls_path in MEASURE_OVERRIDES.items():
         cls = get_class_by_path(
